@@ -15,18 +15,29 @@ y <- x + e
 probitResult <- probit( (y > 0) ~ x )
 print( probitResult )
 summary( probitResult )
+fitted( probitResult )
+residuals( probitResult, type = "response" )
+residuals( probitResult, type = "pearson" )
+residuals( probitResult, type = "deviance" )
 
 ## female labour force participation probability
 lfpResult <- probit( lfp ~ kids + age30.39 + age50.60 + educ + hushrs +
    huseduc + huswage + mtr + motheduc, data = Mroz87 )
 print( lfpResult )
 summary( lfpResult )
-
+fitted( lfpResult )
+residuals( lfpResult, type = "response" )
+residuals( lfpResult, type = "pearson" )
+residuals( lfpResult, type = "deviance" )
 
 ## Greene( 2003 ): example 22.8, page 786 (only probit part )
 greene <- probit( lfp ~ age + I( age^2 ) + faminc + kids + educ, data = Mroz87 )
 print( greene )
 summary( greene )
+fitted( greene )
+residuals( greene, type = "response" )
+residuals( greene, type = "pearson" )
+residuals( greene, type = "deviance" )
 
 ## factors as dependent variable (from Achim Zeileis)
 probit( lfp ~ exper, data = Mroz87 )
